# Copyright (c) 2008-2011 Michael Howitz
# See also LICENSE.txt

import icemac.ab.importer.install
import icemac.addressbook.addressbook
import icemac.addressbook.testing
import icemac.addressbook.utils
import unittest


class TestInstall(unittest.TestCase):

    layer = icemac.addressbook.testing.ADDRESS_BOOK_FUNCTIONAL_LAYER

    def assertLocalUtility(self, ab, iface):
        self.assertTrue(icemac.addressbook.utils.utility_locally_registered(
            ab, iface))

    def assertAttribute(self, ab, attribute, iface):
        self.assertTrue(iface.providedBy(getattr(ab, attribute)))
        self.assertLocalUtility(ab, iface)

    def check_addressbook(self, ab):
        self.assertAttribute(
            ab, 'importer', icemac.ab.importer.interfaces.IImporter)

    def setUp(self):
        self.ab = self.layer['addressbook']

    def test_create(self):
        icemac.addressbook.addressbook.create_address_book_infrastructure(
            self.ab)
        icemac.ab.importer.install.install_importer(self.ab)
        self.check_addressbook(self.ab)

    def test_recall_create(self):
        icemac.addressbook.addressbook.create_address_book_infrastructure(
            self.ab)
        icemac.ab.importer.install.install_importer(self.ab)
        icemac.ab.importer.install.install_importer(self.ab)
        self.check_addressbook(self.ab)



# Copyright (c) 2008-2011 Michael Howitz
# See also LICENSE.txt
# $Id: testing.py 1373 2011-11-03 20:01:08Z icemac $

import icemac.ab.importer.browser
import icemac.addressbook.testing


class _ImporterLayer(icemac.addressbook.testing._ZCMLAndZODBLayer):
    """Layer to test the importer."""

    package = icemac.ab.importer.browser
    defaultBases = (icemac.addressbook.testing.WSGI_TEST_BROWSER_LAYER,)


ImporterLayer = _ImporterLayer(name='ImporterLayer')



# -*- coding: latin-1 -*-
# Copyright (c) 2008-2011 Michael Howitz
# See also LICENSE.txt
# $Id: tests.py 1284 2011-07-26 18:54:04Z icemac $

import icemac.addressbook.testing
import icemac.ab.importer.browser.testing


def test_suite():
    return icemac.addressbook.testing.DocFileSuite(
        "constraints.txt",
        "edgecases.txt",
        "keywords.txt",
        "multientries.txt",
        "wizard.txt",
        "userfields.txt",
        package='icemac.ab.importer.browser.wizard',
        layer=icemac.ab.importer.browser.testing.ImporterLayer,
        )
